@@ -123,33 +123,33 @@ class Payments(Resource):
                         }
                     })
 
+                if 'account_id' in payload.keys():
+                    data.update({
+                        "DepositToAccountRef": {
+                            "value": payload.get("account_id", "")
+                        }
+                    })
+
                 if 'reference' in payload.keys():
                     data.update({
                         "PaymentRefNum": payload.get("reference", "")
                     })
                 
-                # if 'line' in additional_properties.keys():
-                #     payment.update({
-                #         "Line": additional_properties.get("line", {})
-                #     })
-                    
-                #     additional_properties.pop("line")
-                
-                invoices = payload.get("invoices", [])
+                invoices = payload.get("invoice_payments", [])
 
                 for i in range(len(invoices)):
                     invoice = {}
                     if 'amount' in invoices[i].keys():
                         invoice.update({
-                            "Amount": payload.get("amount", "")
+                            "Amount": invoices[i].get("amount", "")
                         })
 
                     if 'invoice_id' in invoices[i].keys():
                         invoice.update({
                             "LinkedTxn": [
                                 {
-                                    "TxnId": invoices[i].pop('invoice_id'),
-                                    "TxnType": "Invoice"
+                                    "TxnId": invoices[i].get('invoice_id',""),
+                                    "TxnType": payload.get("payment_type", "Invoice")
                                 }
                             ]
                         })
@@ -347,16 +347,17 @@ class Payments(Resource):
                 if 'customer_id' in payload.keys():
                     payment.update({
                         "Account": {
-                            "AccountID": payload.get("customer_id", "")
+                            "AccountID": payload.get("account_id", "")
                         }
                     })
 
-                if 'invoice' in additional_properties.keys():
+                if 'invoice_id' in payload.keys():
                     payment.update({
-                        "Invoice": additional_properties.get("invoice", {})
+                        "Invoice": {
+                            "InvoiceID": payload.get("invoice_id", ""),
+                            "LineItems": payload.get("invoice_payments", []),
+                        }
                     })
-                    
-                    additional_properties.pop("invoice")
 
                 if bool(payment):
                     data.update({
